FileSystemUtils class

Utilities for file system operations

Constructors

FileSystemUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

backupFile(String filePath) Future<String>
Create a backup of a file
fileExists(String filePath) bool
Check if a file exists at the given path
findAndroidDir(String projectDir) String?
Find Android directory in a Flutter project
findAppBuildGradle(String androidDir) String?
Find app build.gradle file
findGradleWrapperProperties(String androidDir) String?
Find gradle wrapper properties file
findRootBuildGradle(String androidDir) String?
Find project build.gradle file
readFile(String filePath) Future<String>
Read the contents of a file
writeFile(String filePath, String content) Future<void>
Write content to a file