GradleDoctor class

Class to check Gradle-related configuration in Flutter projects

Constructors

GradleDoctor(String androidDir)
Create a new Gradle doctor

Properties

androidDir String
The Android directory of the Flutter project
final
hashCode int
The hash code for this object.
no setterinherited
issues List<IssueModel>
List of issues found during checking
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAgpVersion() Future<void>
Check the Android Gradle Plugin version in the root build.gradle
checkAll() Future<List<IssueModel>>
Check all Gradle-related configurations
checkGradleVersion() Future<void>
Check the Gradle version in gradle-wrapper.properties
checkSdkVersions() Future<void>
Check the SDK versions in the app/build.gradle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

latestAgpVersion → const String
Latest known compatible Android Gradle Plugin version
latestGradleVersion → const String
Latest known compatible Gradle version
minCompileSdkVersion → const int
Minimum recommended compileSdkVersion
minSdkVersion → const int
Minimum recommended minSdkVersion
recommendedTargetSdkVersion → const int
Recommended targetSdkVersion