KotlinDoctor class

Class to check Kotlin-related configuration in Flutter projects

Constructors

KotlinDoctor(String androidDir)
Create a new Kotlin doctor

Properties

androidDir String
The Android directory of the Flutter project
final
hashCode int
The hash code for this object.
no setterinherited
issues List<IssueModel>
List of issues found during checking
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAll() Future<List<IssueModel>>
Check all Kotlin-related configurations
checkKotlinExtension() Future<void>
Check if Kotlin Android extensions plugin is being used (deprecated)
checkKotlinVersion() Future<void>
Check the Kotlin version in the root build.gradle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

latestKotlinVersion → const String
Latest known compatible Kotlin version