FlutterEnvDoctor class
Main class for Flutter Environment Doctor
Constructors
- FlutterEnvDoctor({required String projectDir, bool backup = false, bool dryRun = false})
- Create a new Flutter Environment Doctor
Properties
- backup → bool
-
Whether to backup files before modifying them
final
- dryRun → bool
-
Whether to do a dry run without applying changes
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
issues
→ List<
IssueModel> -
List of issues found during checking
final
- projectDir → String
-
The Flutter project directory to check
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
check(
) → Future< List< IssueModel> > - Check the Flutter project for issues
-
fix(
{bool applyAll = false}) → Future< List< String> > - Fix the issues in the Flutter project
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printSummary(
) → void - Print a summary of the issues found
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited