IssueModel class

Represents an issue found in the Flutter project environment

Constructors

IssueModel({required String filePath, required String description, required String currentValue, required String recommendedValue, bool isCritical = false})
Create a new issue model

Properties

currentValue String
The current value causing the issue
final
description String
The issue description
final
filePath String
The file path where the issue was found
final
hashCode int
The hash code for this object.
no setterinherited
isCritical bool
Whether the issue is critical or just a warning
final
recommendedValue String
The recommended value to fix the issue
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited